
Name:		xsd
Version:	4.1.0
Release:	%mkrel 0.1.a12
Summary:	W3C XML schema to C++ data binding compiler

Group:		Development/C++
# Exceptions permit otherwise GPLv2 incompatible combination with ASL 2.0
License:	GPLv2 with exceptions and ASL 2.0  
URL:		https://www.codesynthesis.com/products/xsd/
Source0:	https://codesynthesis.com/~boris/tmp/xsd/%{version}.a11/xsd-%{version}.a11+dep.tar.bz2
# http://anonscm.debian.org/cgit/collab-maint/xsd.git/tree/debian/patches/0001-xsd_xsdcxx-rename.patch
Patch0:		%{name}-%{version}-xsdcxx-rename.patch

# Remove tests for character reference values unsupported by Xerces-C++ 3.2
# https://anonscm.debian.org/cgit/collab-maint/xsd.git/diff/debian/patches/0110-xerces-c3.2.patch?id=442e98604d4158dae11056c4f94aaa655cb480fa
Patch1: %{name}-xerces_3-2.patch

BuildRequires:	boost-devel
BuildRequires:	pkgconfig(xerces-c)
BuildRequires:	m4
# Requires:  ace-devel - only needed for applications using
#                        Adaptive Communication Environment (ACE) streams,
#                        enable when Fedora gets ACE packages.
#                        See http://www.cs.wustl.edu/~schmidt/ACE.html and
#                        https://bugzilla.redhat.com/show_bug.cgi?id=450164

%description
CodeSynthesis XSD is an open-source, cross-platform W3C XML Schema to
C++ data binding compiler. Provided with an XML instance specification
(XML Schema), it generates C++ classes that represent the given
vocabulary as well as parsing and serialization code.
You can then access the data stored in XML using types and functions
that semantically correspond to your application domain rather than
dealing with intricacies of reading and writing XML.


%package	devel
Group:		System/Libraries
Summary:	Development files for xsd
Requires:	xerces-c-devel
Requires:	%{name} = %{version}

%description	devel
This package provides development files for xsd.

%package	doc
BuildArch: noarch
BuildRequires: ghostscript
Group:		Documentation
Summary:	API documentation files for %{name}

%description	doc
This package contains API documentation for %{name}.


%prep
%autosetup -p0 -n xsd-%{version}.a11+dep

%build
%make_build verbose=1 CXX=g++ CC=gcc CXXFLAGS="$RPM_OPT_FLAGS -std=c++14 -fPIC -pie -Wl,-z,now" LDFLAGS="%{__global_ldflags} -fPIC -pie -Wl,-z,now" BOOST_LINK_SYSTEM=y


%install
rm -rf apidocdir

make install_prefix="$RPM_BUILD_ROOT%{_prefix}" install verbose=0 CXXFLAGS="%optflags" BOOST_LINK_SYSTEM=y

# Split API documentation to -doc subpackage.
mkdir apidocdir
mv $RPM_BUILD_ROOT%{_datadir}/doc/xsd/*.{xhtml,css} apidocdir/
mv $RPM_BUILD_ROOT%{_datadir}/doc/xsd/cxx/ apidocdir/
mv $RPM_BUILD_ROOT%{_datadir}/doc/xsd/ docdir/

# Convert to utf-8.
for file in docdir/NEWS; do
    mv $file timestamp
    iconv -f ISO-8859-1 -t UTF-8 -o $file timestamp
    touch -r timestamp $file
done

# Rename binary to xsdcxx to avoid conflicting with mono-web package.
# Sent suggestion to upstream via e-mail 20090707
# they will consider renaming in 4.0.0
mv $RPM_BUILD_ROOT%{_bindir}/xsd $RPM_BUILD_ROOT%{_bindir}/xsdcxx
mv $RPM_BUILD_ROOT%{_mandir}/man1/xsd.1 $RPM_BUILD_ROOT%{_mandir}/man1/xsdcxx.1

# Remove duplicate docs.
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/libxsd

# Remove Microsoft Visual C++ compiler helper files.
rm -rf $RPM_BUILD_ROOT%{_includedir}/xsd/cxx/compilers

# Remove redundant PostScript files that rpmlint grunts about not being UTF8
# See: https://bugzilla.redhat.com/show_bug.cgi?id=502024#c27
# for Boris Kolpackov's explanation about those
find apidocdir -name "*.ps" | xargs rm -f
# Remove other unwanted crap
find apidocdir -name "*.doxygen" \
            -o -name "makefile" \
            -o -name "*.html2ps" | xargs rm -f

%files
%doc docdir/*
%{_bindir}/xsdcxx
%{_mandir}/man1/xsdcxx.1*

%files devel
%{_includedir}/xsd/

%files doc
%doc apidocdir/*


%changelog
* Thu Mar 24 2022 umeabot <umeabot> 4.1.0-0.1.a12.mga9
+ Revision: 1824293
- Mageia 9 Mass Rebuild

* Tue Oct 27 2020 tv <tv> 4.1.0-0.1.a11.mga8
+ Revision: 1639782
- Pre-release 4.1.0.a11
- Force C++14 as this code is not C++17 ready
- Make doc noarch

* Tue Feb 11 2020 umeabot <umeabot> 4.0.0-4.mga8
+ Revision: 1488932
- Mageia 8 Mass Rebuild

* Tue Aug 28 2018 daviddavid <daviddavid> 4.0.0-3.mga7
+ Revision: 1255134
- rebuild for new xerces-c 3.2.1

* Fri Feb 12 2016 umeabot <umeabot> 4.0.0-2.mga6
+ Revision: 959346
- Mageia 6 Mass Rebuild

* Fri Jun 26 2015 sander85 <sander85> 4.0.0-1.mga6
+ Revision: 844879
- New version: 4.0 (synced with Fedora)

* Wed Oct 15 2014 umeabot <umeabot> 3.3.0-15.mga5
+ Revision: 741966
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.3.0-14.mga5
+ Revision: 690769
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 3.3.0-13.mga5
+ Revision: 529305
- Mageia 4 Mass Rebuild

* Wed Apr 10 2013 barjac <barjac> 3.3.0-12.mga4
+ Revision: 409444
- rebuild for boost-1.53

* Mon Jan 14 2013 umeabot <umeabot> 3.3.0-11.mga3
+ Revision: 387392
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 29 2012 fwang <fwang> 3.3.0-10.mga3
+ Revision: 336121
- rebuild for new boost

* Sun Oct 14 2012 ennael <ennael> 3.3.0-9.mga3
+ Revision: 305468
- Documentation group

* Tue Jul 31 2012 fwang <fwang> 3.3.0-8.mga3
+ Revision: 276587
- drop old switch
- rebuild for new boost

* Sun Jul 22 2012 sander85 <sander85> 3.3.0-7.mga3
+ Revision: 273229
- Update to xsd-3.3.0-2+dep upstream tarball, which includes fixes for gcc 4.7

* Wed May 30 2012 kamil <kamil> 3.3.0-6.mga3
+ Revision: 249752
- rebuild against boost 1.49.0

* Mon Nov 28 2011 fwang <fwang> 3.3.0-5.mga2
+ Revision: 173675
- rebuild for new boost
- fix install
- use switch
- build mt flavour
- rebuild for new boost
+ dmorgan <dmorgan>
- Rebuild against new boost

* Sat Apr 16 2011 ennael <ennael> 3.3.0-2.mga1
+ Revision: 86625
- clean spec file
- imported package xsd


* Thu Mar 17 2011 Funda Wang <fwang@mandriva.org> 3.3.0-2mdv2011.0
+ Revision: 646044
- force filesystem v2
- rebuild

* Sun Sep 12 2010 Sander Lepik <sander85@mandriva.org> 3.3.0-1mdv2011.0
+ Revision: 577725
- new version 3.3.0

* Tue Aug 24 2010 Funda Wang <fwang@mandriva.org> 3.2.0-7mdv2011.0
+ Revision: 572522
- rebuild for new boost

* Wed Aug 04 2010 Funda Wang <fwang@mandriva.org> 3.2.0-6mdv2011.0
+ Revision: 566008
- rebuild for new boost

* Mon Feb 08 2010 Anssi Hannula <anssi@mandriva.org> 3.2.0-5mdv2010.1
+ Revision: 501882
- rebuild for new boost

* Wed Feb 03 2010 Funda Wang <fwang@mandriva.org> 3.2.0-4mdv2010.1
+ Revision: 500103
- rebuild for new boost

* Tue Feb 02 2010 Funda Wang <fwang@mandriva.org> 3.2.0-3mdv2010.1
+ Revision: 499665
- rebuild

* Fri Dec 18 2009 Sander Lepik <sander85@mandriva.org> 3.2.0-2mdv2010.1
+ Revision: 479876
- bump release
- update devel requires

* Wed Dec 16 2009 Sander Lepik <sander85@mandriva.org> 3.2.0-1mdv2010.1
+ Revision: 479512
- ace comments restored
- devel files splitted + spec corrected
- import xsd


* Fri Nov 20 2009 Sander Lepik <sander.lepik@eesti.ee> - 3.2.0
- Initial release for Mandriva

* Mon Jul 27 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jul 07 2009 Antti Andreimann <Antti.Andreimann@mail.ee> 3.2.0-4
- Removed redundant PostScript files from the doc package

* Mon Jul 06 2009 Antti Andreimann <Antti.Andreimann@mail.ee> 3.2.0-3
- Added ACE homepage to SPEC file comments
- Added verbose=1 to MAKEFLAGS so compiler flags could be
  verified from build logs.

* Mon Jul 04 2009 Antti Andreimann <Antti.Andreimann@mail.ee> 3.2.0-2
- Changed License tag to clarify which exceptions we are talking about

* Wed May 20 2009 Antti Andreimann <Antti.Andreimann@mail.ee> 3.2.0-1
- Initial RPM release.

